pub enum StackDirection {
TopToBottom,
BottomToTop,
}Expand description
Direction used by stack flows when emitting vertical cells.
Variants
TopToBottom
Place cells from the current row start downward.
BottomToTop
Place cells from the bottom of the current scope upward.