pub struct NodeInteraction {
pub control: ControlState,
pub result: ResourceState,
}Expand description
Interaction data sampled for a retained node in one frame.
Fields
control: ControlStateControl state observed while handling the node this frame.
result: ResourceStateResource state returned by the node this frame.
Implementations
Sourceimpl NodeInteraction
impl NodeInteraction
Sourcepub const fn new(control: ControlState, result: ResourceState) -> Self
pub const fn new(control: ControlState, result: ResourceState) -> Self
Creates an interaction snapshot for one node.